photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerrename.h
branchRCL_3
changeset 15 191387a8b767
parent 0 4e91876724a2
--- a/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerrename.h	Wed Apr 14 15:57:24 2010 +0300
+++ b/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerrename.h	Tue Apr 27 16:37:53 2010 +0300
@@ -41,12 +41,14 @@
 	{
 public:
     /**
      * Two-phase constructor
      * @param aMediaListProvider object that provides the media list
      * @param aHasToolbarItem Whether Command Should be toolbar item (ETrue - if toolbar item)
      */
 	IMPORT_C static CGlxCommandHandlerRename* NewL(
-	    MGlxMediaListProvider* aMediaListProvider, TBool aHasToolbarItem );
+			MGlxMediaListProvider* aMediaListProvider, TBool aHasToolbarItem,
+			const TDesC& aFileName);
 	    
 	/** Destructor */
 	IMPORT_C ~CGlxCommandHandlerRename();
@@ -75,7 +77,7 @@
 
 private:
     /** Second phase constructor */
-	void ConstructL();
+	void ConstructL(const TDesC& aFileName);
 
     /**
      *  Constructor
@@ -41,12 +41,14 @@
 public:
     /**
-     * Two-phase constructor
-     * @param aMediaListProvider object that provides the media list
-     * @param aHasToolbarItem Whether Command Should be toolbar item (ETrue - if toolbar item)
-     */
+	 * Two-phase constructor
+	 * @param aMediaListProvider object that provides the media list
+	 * @param aHasToolbarItem Whether Command Should be toolbar item (ETrue - if toolbar item)
+	 * @param aFileName resource file
+	 */
 	IMPORT_C static CGlxCommandHandlerRename* NewL(